<template>
    <div>
        <v-app class="vue-front-end-fixed">
            <div class="location_selector">
              <v-row>
                <v-col cols="12 pb-0">
                  <div class="mt-2">{{ location_name }} <a href="javascript:;" @click="changeLocation()" class="change_text">CHANGE</a></div>
                </v-col>
                
              </v-row></div>
              <location-confirmation ref="change_location" 
              width="600"
              :confirm_button_color="'#E5007D'"
              :cancel_button_color="'grey'"
              :show_close="false"
              :msg="confirmation.msg" 
              :show_confirm="false"
              @confirm="confirmNewLocation"
              @close="closeModel"
              >
                <v-row>
                  <v-col cols="12">
                    <v-btn
                          :color="'#FFFFFF'"
                          class="black--text float-right"
                          @click="$refs.change_location.view = false"
                          v-if="this.form.location_id!=null"
                          icon
                        >
                          <v-icon>mdi-close</v-icon>
                        </v-btn>
                  </v-col>
                  <v-col cols="12" class="text-center">
                    <h3>Where are you delivering to? </h3>
                    <h6>Please click your location to optimize the shopping experience to your region</h6>
                  </v-col>
                  <v-col cols="12" class="text-center">
                    
                      <div class="location_div" v-for="(location,i) in location_list" :key="i">
                        <v-btn
                          :color="'#FFFFFF'"
                          class="black--text"
                          :loading="location.loading"
                          @click="selectLocation(location,i)"
                        >
                          {{ location.name }}
                        </v-btn>
                      </div>
                    
                  </v-col>
                  
                </v-row>
              </location-confirmation>
              <location-confirmation ref="confirmation" 
              width="600"
              :confirm_button_color="'#FFFF00'"
              :cancel_button_color="'grey'"
              :show_close="true"
              :msg="confirmation.msg" 
              @confirm="confirmNewLocation"
              @close="closeModel"
              >
              </location-confirmation>
        </v-app> 
    </div>
</template>
<script>
import LocationConfirmation from './LocationConfirmation.vue';
import options from '~/assets/options';
export default {
    components : {
      LocationConfirmation
    },
    data() {
        return {
            location_list : this.$store.state.front_end_data.location_list,
            domain_id : this.$store.state.front_end_data.domain_id,
            location_name : "",
            options       : options,
            confirmation :{
                msg           : "",
            },
            form      : this.getFormFields()
        }
    },
    mounted() {
      let index = this.location_list.findIndex(x=>x.id==this.form.location_id);
        if(index>=0) {
          this.location_name = this.location_list[index]['name'];
        }
        let domain = this.$store.state.front_end_data.domain;
      if(this.form.location_id==null && domain['is_location_exists']) {
        this.changeLocation();
      }
    },
    methods:{
      getFormFields() {
        return {
              location_id : this.$store.state.front_end_data.location,
              current_location_id : this.$store.state.front_end_data.location,
              current_host        : this.$auth.$storage.getUniversal('current_host'),
            }
      },
      closeModel() {
        this.form = this.getFormFields();
      },
      confirmNewLocation() {
        this.$refs.confirmation.view = false;
      },
      selectLocation(location,i) {
        this.location_list[i].loading = true;
        this.form.location_id = location.id;
        this.$axios.$post('/api/change-location',this.form)
        .then(resp=>{
          if(!resp.success) {
            this.confirmation.msg = resp.error;
            this.location_list[i].loading = false;
            this.$refs.confirmation.view = true;
          }
          else {
            this.$auth.$storage.setUniversal('location', resp.location_id);
            this.$router.go();
          }
        });
      },
      changeLocation() {
        this.$refs.change_location.view = true;
      }
    }
}
</script>